﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Microsoft.Research.Kinect.Nui;

namespace KinectDepth01
{
    public partial class Form1 : Form
    {
        Runtime nui;
        byte[] depthFrame32 = new byte[320 * 240 * 4];
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            nui = new Runtime();
            try
            {
                nui.Initialize(RuntimeOptions.UseDepthAndPlayerIndex);
            }
            catch (InvalidOperationException)
            {
                MessageBox.Show("Runtime initialization failed!");
                return;
            }

            try
            {
                nui.DepthStream.Open(ImageStreamType.Depth, 2, ImageResolution.Resolution320x240, ImageType.DepthAndPlayerIndex);

            }
            catch (InvalidOperationException)
            {
                MessageBox.Show("Fail to open stream.");
                return;
            }

            nui.DepthFrameReady += new EventHandler<ImageFrameReadyEventArgs>(nui_DepthFrameReady);
        }

        void nui_DepthFrameReady(object sender, ImageFrameReadyEventArgs e)
        {
            PlanarImage Image = e.ImageFrame.Image;
            int[] personDepth = personDepthFrame(Image.Bits);

            textBox1.Text = personDepth[1].ToString();
            textBox2.Text = personDepth[2].ToString();
            textBox3.Text = personDepth[3].ToString();
            textBox4.Text = personDepth[4].ToString();
            textBox5.Text = personDepth[5].ToString();
            textBox6.Text = personDepth[6].ToString();
            textBox7.Text = personDepth[7].ToString();
        }

        int[] personDepthFrame(byte[] depthFrame16)
        {
            int[] cntDepth = new int[8];
            int[] aveDepth = new int[8];
            for (int i = 0; i < 8; i++)
            {
                aveDepth[i] = 0;
                cntDepth[i] = 0;
            }
            for (int i16 = 0, i32 = 0; i16 < depthFrame16.Length && i32 < depthFrame32.Length; i16 += 2, i32 += 4)
            {
                int player = depthFrame16[i16] & 0x07;
                int realDepth = (depthFrame16[i16 + 1] << 5) | (depthFrame16[i16] >> 3);

                // 異なる人ごとに集計
                switch (player)
                {
                    case 0:
                        aveDepth[0] = aveDepth[0] + realDepth;
                        cntDepth[0] = cntDepth[0] + 1;
                        break;
                    case 1:
                        aveDepth[1] = aveDepth[1] + realDepth;
                        cntDepth[1] = cntDepth[1] + 1;
                        break;
                    case 2:
                        aveDepth[2] = aveDepth[2] + realDepth;
                        cntDepth[2] = cntDepth[2] + 1;
                        break;
                    case 3:
                        aveDepth[3] = aveDepth[3] + realDepth;
                        cntDepth[3] = cntDepth[3] + 1;
                        break;
                    case 4:
                        aveDepth[4] = aveDepth[4] + realDepth;
                        cntDepth[4] = cntDepth[4] + 1;
                        break;
                    case 5:
                        aveDepth[5] = aveDepth[5] + realDepth;
                        cntDepth[5] = cntDepth[5] + 1;
                        break;
                    case 6:
                        aveDepth[6] = aveDepth[6] + realDepth;
                        cntDepth[6] = cntDepth[6] + 1;
                        break;
                    case 7:
                        aveDepth[7] = aveDepth[7] + realDepth;
                        cntDepth[7] = cntDepth[7] + 1;
                        break;
                }
            }

            for (int i = 0; i < 8; i++)
            {
                if (cntDepth[i] != 0) aveDepth[i] = aveDepth[i] / cntDepth[i];
                else aveDepth[i] = 0;
            }
            return aveDepth;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            nui.Uninitialize();
            Environment.Exit(0);
        }
    }
}
